@@ -5,7 +5,7 @@ use num_traits::FromPrimitive;
 use proptest_derive::Arbitrary;
 
 /// Magnet detection status parsing/conversion error.
-#[derive(Debug, PartialEq)]
+#[derive(Debug, PartialEq, Clone, Copy)]
 pub enum Error {
     /// Bit pattern not valid for magnet detection status.
     InvalidBitPattern(u8),
@@ -47,7 +47,7 @@ impl TryFrom<[u8; 1]> for Status {
 
 impl From<Status> for u8 {
     fn from(status: Status) -> Self {
-        status as u8
+        status as Self
     }
 }
 
